summaryrefslogtreecommitdiffstats
path: root/kmail/folderdiaacltab.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/folderdiaacltab.cpp')
-rw-r--r--kmail/folderdiaacltab.cpp68
1 files changed, 34 insertions, 34 deletions
diff --git a/kmail/folderdiaacltab.cpp b/kmail/folderdiaacltab.cpp
index 58130a05b..90903fdb1 100644
--- a/kmail/folderdiaacltab.cpp
+++ b/kmail/folderdiaacltab.cpp
@@ -20,11 +20,11 @@
*
* In addition, as a special exception, the copyright holders give
* permission to link the code of this program with any edition of
- * the Qt library by Trolltech AS, Norway (or with modified versions
- * of Qt that use the same license as Qt), and distribute linked
+ * the TQt library by Trolltech AS, Norway (or with modified versions
+ * of TQt that use the same license as TQt), and distribute linked
* combinations including the two. You must obey the GNU General
* Public License in all respects for all of the code used other than
- * Qt. If you modify this file, you may extend this exception to
+ * TQt. If you modify this file, you may extend this exception to
* your version of the file, but you are not obligated to do so. If
* you do not wish to do so, delete this exception statement from
* your version.
@@ -83,8 +83,8 @@ static const struct {
};
-KMail::ACLEntryDialog::ACLEntryDialog( IMAPUserIdFormat userIdFormat, const TQString& caption, TQWidget* parent, const char* name )
- : KDialogBase( parent, name, true /*modal*/, caption,
+KMail::ACLEntryDialog::ACLEntryDialog( IMAPUserIdFormat userIdFormat, const TQString& caption, TQWidget* tqparent, const char* name )
+ : KDialogBase( tqparent, name, true /*modal*/, caption,
KDialogBase::Ok|KDialogBase::Cancel, KDialogBase::Ok, true /*sep*/ )
, mUserIdFormat( userIdFormat )
{
@@ -115,7 +115,7 @@ KMail::ACLEntryDialog::ACLEntryDialog( IMAPUserIdFormat userIdFormat, const TQSt
}
topLayout->setRowStretch(2, 10);
- TQLabel *noteLabel = new TQLabel( i18n( "<b>Note: </b>Renaming requires write permissions on the parent folder." ), page );
+ TQLabel *noteLabel = new TQLabel( i18n( "<b>Note: </b>Renaming requires write permissions on the tqparent folder." ), page );
topLayout->addMultiCellWidget( noteLabel, 2, 2, 0, 2 );
connect( mUserIdLineEdit, TQT_SIGNAL( textChanged( const TQString& ) ), TQT_SLOT( slotChanged() ) );
@@ -139,7 +139,7 @@ static TQString addresseeToUserId( const KABC::Addressee& addr, IMAPUserIdFormat
if ( userIdFormat == FullEmail )
return email;
else { // mUserIdFormat == UserName
- email.truncate( email.find( '@' ) );
+ email.truncate( email.tqfind( '@' ) );
return email;
}
}
@@ -192,7 +192,7 @@ unsigned int KMail::ACLEntryDialog::permissions() const
// class KMail::FolderDiaACLTab::ListView : public KListView
// {
// public:
-// ListView( TQWidget* parent, const char* name = 0 ) : KListView( parent, name ) {}
+// ListView( TQWidget* tqparent, const char* name = 0 ) : KListView( tqparent, name ) {}
// };
class KMail::FolderDiaACLTab::ListViewItem : public KListViewItem
@@ -250,7 +250,7 @@ static TQString permissionsToUserString( unsigned int permissions, const TQStrin
void KMail::FolderDiaACLTab::ListViewItem::setPermissions( unsigned int permissions )
{
mPermissions = permissions;
- setText( 1, permissionsToUserString( permissions, TQString::null ) );
+ setText( 1, permissionsToUserString( permissions, TQString() ) );
}
void KMail::FolderDiaACLTab::ListViewItem::load( const ACLListEntry& entry )
@@ -260,7 +260,7 @@ void KMail::FolderDiaACLTab::ListViewItem::load( const ACLListEntry& entry )
// It's ok in distribution list names though, that's why this check is only done here
// and also why there's no validator on the lineedit.
if ( entry.userId.tqcontains( ' ' ) )
- kdWarning(5006) << "Userid tqcontains a space!!! '" << entry.userId << "'" << endl;
+ kdWarning(5006) << "Userid contains a space!!! '" << entry.userId << "'" << endl;
setUserId( entry.userId );
mPermissions = entry.permissions;
@@ -297,14 +297,14 @@ void KMail::FolderDiaACLTab::ListViewItem::save( ACLList& aclList,
TQString email = (*it).email;
if ( email.isEmpty() )
email = addresseeToUserId( (*it).addressee, userIdFormat );
- ACLListEntry entry( email, TQString::null, mPermissions );
+ ACLListEntry entry( email, TQString(), mPermissions );
entry.changed = true;
aclList.append( entry );
}
} else { // it wasn't a distribution list
ACLListEntry entry( userId(), mInternalRightsList, mPermissions );
if ( mModified ) {
- entry.internalRightsList = TQString::null;
+ entry.internalRightsList = TQString();
entry.changed = true;
}
aclList.append( entry );
@@ -313,8 +313,8 @@ void KMail::FolderDiaACLTab::ListViewItem::save( ACLList& aclList,
////
-KMail::FolderDiaACLTab::FolderDiaACLTab( KMFolderDialog* dlg, TQWidget* parent, const char* name )
- : FolderDiaTab( parent, name ),
+KMail::FolderDiaACLTab::FolderDiaACLTab( KMFolderDialog* dlg, TQWidget* tqparent, const char* name )
+ : FolderDiaTab( tqparent, name ),
mImapAccount( 0 ),
mUserRights( 0 ),
mUserRightsState( KMail::ACLJobs::NotFetchedYet ),
@@ -363,7 +363,7 @@ KMail::FolderDiaACLTab::FolderDiaACLTab( KMFolderDialog* dlg, TQWidget* parent,
connect( this, TQT_SIGNAL( changed(bool) ), TQT_SLOT( slotChanged(bool) ) );
}
// Warning before save() this will return the url of the _parent_ folder, when creating a new one
KURL KMail::FolderDiaACLTab::imapURL() const
{
KURL url = mImapAccount->getUrl();
@@ -398,9 +398,9 @@ void KMail::FolderDiaACLTab::load()
if ( mDlg->folder() ) {
// existing folder
initializeWithValuesFromFolder( mDlg->folder() );
- } else if ( mDlg->parentFolder() ) {
+ } else if ( mDlg->tqparentFolder() ) {
// new folder
- initializeWithValuesFromFolder( mDlg->parentFolder() );
+ initializeWithValuesFromFolder( mDlg->tqparentFolder() );
mChanged = true; // ensure that saving happens
}
@@ -412,7 +412,7 @@ void KMail::FolderDiaACLTab::load()
// but the default value is determined from the current user's own id.
TQString defaultFormat = "fullemail";
// warning mImapAccount can be 0 if creating a subsubsubfolder with dimap... (bug?)
- if ( mImapAccount && mImapAccount->login().find('@') == -1 )
+ if ( mImapAccount && mImapAccount->login().tqfind('@') == -1 )
defaultFormat = "username"; // no @ found, so we assume it's just the username
KConfigGroup configGroup( kmkernel->config(), "IMAP" );
TQString str = configGroup.readEntry( "UserIdFormat", defaultFormat );
@@ -421,7 +421,7 @@ void KMail::FolderDiaACLTab::load()
mUserIdFormat = UserName;
if ( mFolderType == KMFolderTypeCachedImap ) {
- KMFolder* folder = mDlg->folder() ? mDlg->folder() : mDlg->parentFolder();
+ KMFolder* folder = mDlg->folder() ? mDlg->folder() : mDlg->tqparentFolder();
KMFolderCachedImap* folderImap = static_cast<KMFolderCachedImap*>( folder->storage() );
if ( mUserRightsState == KMail::ACLJobs::FetchFailed ||
folderImap->aclListState() == KMail::ACLJobs::FetchFailed ) {
@@ -450,18 +450,18 @@ void KMail::FolderDiaACLTab::load()
mLabel->setText( i18n( "Error: no IMAP account defined for this folder" ) );
return;
}
- KMFolder* folder = mDlg->folder() ? mDlg->folder() : mDlg->parentFolder();
+ KMFolder* folder = mDlg->folder() ? mDlg->folder() : mDlg->tqparentFolder();
if ( folder && folder->storage() == mImapAccount->rootFolder() )
return; // nothing to be done for the (virtual) account folder
mLabel->setText( i18n( "Connecting to server %1, please wait..." ).arg( mImapAccount->host() ) );
ImapAccountBase::ConnectionState state = mImapAccount->makeConnection();
if ( state == ImapAccountBase::Error ) { // Cancelled by user, or slave can't start
- slotConnectionResult( -1, TQString::null );
+ slotConnectionResult( -1, TQString() );
} else if ( state == ImapAccountBase::Connecting ) {
connect( mImapAccount, TQT_SIGNAL( connectionResult(int, const TQString&) ),
this, TQT_SLOT( slotConnectionResult(int, const TQString&) ) );
} else { // Connected
- slotConnectionResult( 0, TQString::null );
+ slotConnectionResult( 0, TQString() );
}
}
@@ -481,7 +481,7 @@ void KMail::FolderDiaACLTab::slotConnectionResult( int errorCode, const TQString
if ( mUserRightsState != KMail::ACLJobs::Ok ) {
connect( mImapAccount, TQT_SIGNAL( receivedUserRights( KMFolder* ) ),
this, TQT_SLOT( slotReceivedUserRights( KMFolder* ) ) );
- KMFolder* folder = mDlg->folder() ? mDlg->folder() : mDlg->parentFolder();
+ KMFolder* folder = mDlg->folder() ? mDlg->folder() : mDlg->tqparentFolder();
mImapAccount->getUserRights( folder, mImapPath );
}
else
@@ -495,7 +495,7 @@ void KMail::FolderDiaACLTab::slotReceivedUserRights( KMFolder* folder )
return;
}
- if ( folder == mDlg->folder() ? mDlg->folder() : mDlg->parentFolder() ) {
+ if ( folder == mDlg->folder() ? mDlg->folder() : mDlg->tqparentFolder() ) {
KMFolderImap* folderImap = static_cast<KMFolderImap*>( folder->storage() );
mUserRights = folderImap->userRights();
mUserRightsState = folderImap->userRightsState();
@@ -505,15 +505,15 @@ void KMail::FolderDiaACLTab::slotReceivedUserRights( KMFolder* folder )
void KMail::FolderDiaACLTab::startListing()
{
- // List ACLs of folder - or its parent, if creating a new folder
- mImapAccount->getACL( mDlg->folder() ? mDlg->folder() : mDlg->parentFolder(), mImapPath );
+ // List ACLs of folder - or its tqparent, if creating a new folder
+ mImapAccount->getACL( mDlg->folder() ? mDlg->folder() : mDlg->tqparentFolder(), mImapPath );
connect( mImapAccount, TQT_SIGNAL(receivedACL( KMFolder*, KIO::Job*, const KMail::ACLList& )),
this, TQT_SLOT(slotReceivedACL( KMFolder*, KIO::Job*, const KMail::ACLList& )) );
}
void KMail::FolderDiaACLTab::slotReceivedACL( KMFolder* folder, KIO::Job* job, const KMail::ACLList& aclList )
{
- if ( folder == ( mDlg->folder() ? mDlg->folder() : mDlg->parentFolder() ) ) {
+ if ( folder == ( mDlg->folder() ? mDlg->folder() : mDlg->tqparentFolder() ) ) {
disconnect( mImapAccount, TQT_SIGNAL(receivedACL( KMFolder*, KIO::Job*, const KMail::ACLList& )),
this, TQT_SLOT(slotReceivedACL( KMFolder*, KIO::Job*, const KMail::ACLList& )) );
@@ -642,7 +642,7 @@ void KMail::FolderDiaACLTab::slotRemoveACL()
emit changed(true);
}
-KMail::FolderDiaTab::AccepStatus KMail::FolderDiaACLTab::accept()
+KMail::FolderDiaTab::AcceptqStatus KMail::FolderDiaACLTab::accept()
{
if ( !mChanged || !mImapAccount )
return Accepted; // (no change made), ok for accepting the dialog immediately
@@ -706,7 +706,7 @@ bool KMail::FolderDiaACLTab::save()
for ( TQStringList::ConstIterator rit = mRemovedACLs.begin(); rit != mRemovedACLs.end(); ++rit ) {
// We use permissions == -1 to signify deleting. At least on cyrus, setacl(0) or deleteacl are the same,
// but I'm not sure if that's true for all servers.
- ACLListEntry entry( *rit, TQString::null, -1 );
+ ACLListEntry entry( *rit, TQString(), -1 );
entry.changed = true;
aclList.append( entry );
}
@@ -723,15 +723,15 @@ bool KMail::FolderDiaACLTab::save()
mACLList = aclList;
- KMFolderImap* parentImap = mDlg->parentFolder() ? static_cast<KMFolderImap*>( mDlg->parentFolder()->storage() ) : 0;
+ KMFolderImap* tqparentImap = mDlg->tqparentFolder() ? static_cast<KMFolderImap*>( mDlg->tqparentFolder()->storage() ) : 0;
if ( mDlg->isNewFolder() ) {
// The folder isn't created yet, wait for it
// It's a two-step process (mkdir+listDir) so we wait for the dir listing to be complete
- connect( parentImap, TQT_SIGNAL( directoryListingFinished(KMFolderImap*) ),
+ connect( tqparentImap, TQT_SIGNAL( directoryListingFinished(KMFolderImap*) ),
this, TQT_SLOT( slotDirectoryListingFinished(KMFolderImap*) ) );
} else {
- slotDirectoryListingFinished( parentImap );
+ slotDirectoryListingFinished( tqparentImap );
}
return true;
}
@@ -739,7 +739,7 @@ bool KMail::FolderDiaACLTab::save()
void KMail::FolderDiaACLTab::slotDirectoryListingFinished(KMFolderImap* f)
{
if ( !f ||
- f != static_cast<KMFolderImap*>( mDlg->parentFolder()->storage() ) ||
+ f != static_cast<KMFolderImap*>( mDlg->tqparentFolder()->storage() ) ||
!mDlg->folder() ||
!mDlg->folder()->storage() ) {
emit readyForAccept();
@@ -754,7 +754,7 @@ void KMail::FolderDiaACLTab::slotDirectoryListingFinished(KMFolderImap* f)
KIO::Job* job = ACLJobs::multiSetACL( mImapAccount->slave(), imapURL(), mACLList );
ImapAccountBase::jobData jd;
- jd.total = 1; jd.done = 0; jd.parent = 0;
+ jd.total = 1; jd.done = 0; jd.tqparent = 0;
mImapAccount->insertJob(job, jd);
connect(job, TQT_SIGNAL(result(KIO::Job *)),
@@ -363,7 +363,7 @@ KMail::FolderDiaACLTab::FolderDiaACLTab( KMFolderDialog* dlg, TQWidget* parent,
connect( this, TQT_SIGNAL( changed(bool) ), TQT_SLOT( slotChanged(bool) ) );
}
-// Warning before save() this will return the url of the _parent_ folder, when creating a new one
+// Warning before save() this will return the url of the _tqparent_ folder, when creating a new one
KURL KMail::FolderDiaACLTab::imapURL() const
{